@@ -1,20 +1,67 @@
 package Archive::BagIt::Fast;
 use strict;
 use warnings;
-use IO::AIO;
-use Carp;
-use Time::HiRes qw(time);
+use Carp qw( croak );
+use Time::HiRes qw( time );
 use Moo;
+use IO::AIO ();
+use Net::SSLeay ();
 extends "Archive::BagIt";
 
-our $VERSION = '0.073'; # TRIAL VERSION
 
+our $VERSION = '0.082'; # TRIAL VERSION
+
+# ABSTRACT: A module to use IO::AIO to get better performance
+
+
+sub BEGIN {
+    Net::SSLeay::OpenSSL_add_all_digests();
+}
+
+sub _small_digest {
+    my $digestobj = shift;
+    my $fh = shift;
+    my $filesize = shift;
+    my $data;
+    sysread $fh, $data, $filesize;
+    Net::SSLeay::EVP_DigestUpdate($digestobj->_digest, $data);
+    my $result = Net::SSLeay::EVP_DigestFinal($digestobj->_digest);
+    Net::SSLeay::EVP_MD_CTX_destroy($digestobj->_digest);
+    delete $digestobj->{_digest};
+    my $digest = unpack('H*', $result);
+    return $digest;
+}
+
+sub _large_digest {
+    my $digestobj = shift;
+    my $fh = shift;
+    my $filesize = shift;
+    my $data='';
+    if ($filesize > 0) {
+        IO::AIO::mmap $data, $filesize, IO::AIO::PROT_READ, IO::AIO::MAP_SHARED, $fh or croak "mmap: $!";
+    }
+    Net::SSLeay::EVP_DigestUpdate($digestobj->_digest, $data);
+    my $result = Net::SSLeay::EVP_DigestFinal($digestobj->_digest);
+    Net::SSLeay::EVP_MD_CTX_destroy($digestobj->_digest);
+    delete $digestobj->{_digest};
+    my $digest = unpack('H*', $result);
+    return $digest;
+}
 
 has 'digest_callback' => (
     is      => 'ro',
     lazy    => 1,
+
     builder => sub {
         my ($self) = shift;
+        #my $sub = sub {
+        #    my ($digestobj, $filename) = @_;
+        #    open(my $fh, "<:raw", "$filename") or croak ("Cannot open $filename, $!");
+        #    binmode($fh);
+        #    my $digest = $digestobj->get_hash_string($fh);
+        #    close $fh || croak("could not close file '$filename', $!");
+        #    return $digest;
+        #};
         my $sub = sub {
             my $digestobj = shift;
             my $filename =shift;
@@ -26,22 +73,11 @@ has 'digest_callback' => (
             $self->{stats}->{size} += $filesize;
             my $start_time = time();
             my $digest;
-            my $data;
             if ($filesize < $MMAP_MIN ) {
-                sysread $fh, $data, $filesize;
-                Net::SSLeay::EVP_DigestUpdate($digestobj->_digest, $data);
-                my $result = Net::SSLeay::EVP_DigestFinal($digestobj->_digest);
-                Net::SSLeay::EVP_MD_CTX_destroy($digestobj->_digest);
-                delete $digestobj->{_digest};
-                $digest = unpack('H*', $result);
+                return _small_digest($digestobj, $fh, $filesize);
             }
             elsif ( $filesize < 1500000000) {
-                IO::AIO::mmap $data, $filesize, IO::AIO::PROT_READ, IO::AIO::MAP_SHARED, $fh or croak "mmap: $!";
-                Net::SSLeay::EVP_DigestUpdate($digestobj->_digest, $data);
-                my $result = Net::SSLeay::EVP_DigestFinal($digestobj->_digest);
-                Net::SSLeay::EVP_MD_CTX_destroy($digestobj->_digest);
-                delete $digestobj->{_digest};
-                $digest = unpack('H*', $result);
+                return _large_digest($digestobj, $fh, $filesize);
             }
             else {
                 $digest = $digestobj->get_hash_string($fh);
@@ -66,11 +102,11 @@ __END__
 
 =head1 NAME
 
-Archive::BagIt::Fast
+Archive::BagIt::Fast - A module to use IO::AIO to get better performance
 
 =head1 VERSION
 
-version 0.073
+version 0.082
 
 =head1 NAME
 
