@@ -1,24 +1,27 @@
-#ABSTRACT: A role that defines the interface to a hashing algorithm
-#
 package Archive::BagIt::Role::Algorithm;
 use strict;
 use warnings;
 use Moo::Role;
+use Carp qw(croak);
+use feature qw( current_sub);
 with 'Archive::BagIt::Role::Plugin';
+# ABSTRACT: A role that defines the interface to a hashing algorithm
+our $VERSION = '0.082'; # TRIAL VERSION
 
 has 'name' => (
     is => 'ro',
 );
 
-
-sub get_hash_string {
+sub get_optimal_bufsize {
     my ($self, $fh) = @_;
-    return;
-}
-
-sub verify_file {
-    my ($self, $fh) = @_;
-    return;
+    my ($dev,$ino,$mode,$nlink,$uid,$gid,$rdev,$size,
+        $atime,$mtime,$ctime,$blksize,$blocks)
+        = stat $fh;
+    # Windows systems return "" for $blksize
+    if ((defined $blksize ) && ($blksize ne "") && ($blksize >= 512)) {
+        return $blksize;
+    }
+    return 8192;
 }
 
 sub register_plugin {
@@ -44,7 +47,7 @@ Archive::BagIt::Role::Algorithm - A role that defines the interface to a hashing
 
 =head1 VERSION
 
-version 0.064
+version 0.082
 
 =head1 AVAILABILITY
 
@@ -63,7 +66,7 @@ Rob Schmidt <rjeschmi@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Rob Schmidt and William Wueppelmann and Andreas Romeyke.
+This software is copyright (c) 2021 by Rob Schmidt and William Wueppelmann and Andreas Romeyke.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
