@@ -1,9 +1,11 @@
 package Archive::BagIt::Role::Plugin;
-# ABSTRACT: A role that handles plugin loading
 use strict;
 use warnings;
 use Moo::Role;
+use IO::Async::Loop;
 use namespace::autoclean;
+# ABSTRACT: A role that handles plugin loading
+our $VERSION = '0.082'; # TRIAL VERSION
 
 has plugin_name => (
   is  => 'ro',
@@ -11,9 +13,16 @@ has plugin_name => (
   default => __PACKAGE__,
 );
 
+has '_ioloop' => (
+    is      => 'ro',
+    default => sub {
+        IO::Async::Loop->new();
+    }
+);
+
 has bagit => (
   is  => 'ro',
-  #isa => 'Archive::BagIt::Base',
+  #isa => 'Archive::BagIt',
   required => 1,
   weak_ref => 1,
 );
@@ -39,7 +48,7 @@ Archive::BagIt::Role::Plugin - A role that handles plugin loading
 
 =head1 VERSION
 
-version 0.064
+version 0.082
 
 =head1 AVAILABILITY
 
@@ -58,7 +67,7 @@ Rob Schmidt <rjeschmi@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Rob Schmidt and William Wueppelmann and Andreas Romeyke.
+This software is copyright (c) 2021 by Rob Schmidt and William Wueppelmann and Andreas Romeyke.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
